@@ -1,6 +1,9 @@
-data(neuroblastoma,package="bams")
+data(neuroblastoma,package="neuroblastoma")
 library(plyr)
 minmax <- ddply(neuroblastoma$annotations,.(chromosome),head,1)[,c("min","max")]
+for(N in names(minmax)){
+  minmax[[N]] <- sprintf("%.1f",minmax[[N]]/1e6)
+}
 colnames(minmax) <- c("min = $\\underline r_k$","max = $\\overline r_k$")
 library(reshape2)
 chrom.ann.counts <-
